@@ -36,17 +36,17 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	"github.com/rancher/k3d/v5/cmd/cluster"
-	cfg "github.com/rancher/k3d/v5/cmd/config"
-	"github.com/rancher/k3d/v5/cmd/debug"
-	"github.com/rancher/k3d/v5/cmd/image"
-	"github.com/rancher/k3d/v5/cmd/kubeconfig"
-	"github.com/rancher/k3d/v5/cmd/node"
-	"github.com/rancher/k3d/v5/cmd/registry"
-	cliutil "github.com/rancher/k3d/v5/cmd/util"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	"github.com/rancher/k3d/v5/version"
+	"github.com/k3d-io/k3d/v5/cmd/cluster"
+	cfg "github.com/k3d-io/k3d/v5/cmd/config"
+	"github.com/k3d-io/k3d/v5/cmd/debug"
+	"github.com/k3d-io/k3d/v5/cmd/image"
+	"github.com/k3d-io/k3d/v5/cmd/kubeconfig"
+	"github.com/k3d-io/k3d/v5/cmd/node"
+	"github.com/k3d-io/k3d/v5/cmd/registry"
+	cliutil "github.com/k3d-io/k3d/v5/cmd/util"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	"github.com/k3d-io/k3d/v5/version"
 	"github.com/sirupsen/logrus"
 	"github.com/sirupsen/logrus/hooks/writer"
 )
@@ -409,7 +409,7 @@ Zsh:
 	$ echo "autoload -U compinit; compinit" >> ~/.zshrc
 
 	# To load completions for each session, execute once:
-	$ k3d completion zsh > "${fpath[1]}/k3d"
+	$ k3d completion zsh > "${fpath[1]}/_k3d"
 
 	# You will need to start a new shell for this setup to take effect.
 
