@@ -40,17 +40,18 @@ import (
 	"github.com/docker/go-connections/nat"
 	dockerunits "github.com/docker/go-units"
 	"github.com/imdario/mergo"
-	"github.com/rancher/k3d/v5/pkg/actions"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	"github.com/rancher/k3d/v5/pkg/runtimes/docker"
-	runtimeTypes "github.com/rancher/k3d/v5/pkg/runtimes/types"
+	"github.com/k3d-io/k3d/v5/pkg/actions"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes/docker"
+	runtimeTypes "github.com/k3d-io/k3d/v5/pkg/runtimes/types"
+	"github.com/k3d-io/k3d/v5/version"
 
-	runtimeErrors "github.com/rancher/k3d/v5/pkg/runtimes/errors"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
-	"github.com/rancher/k3d/v5/pkg/types/fixes"
-	"github.com/rancher/k3d/v5/pkg/types/k3s"
-	"github.com/rancher/k3d/v5/pkg/util"
+	runtimeErrors "github.com/k3d-io/k3d/v5/pkg/runtimes/errors"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
+	"github.com/k3d-io/k3d/v5/pkg/types/fixes"
+	"github.com/k3d-io/k3d/v5/pkg/types/k3s"
+	"github.com/k3d-io/k3d/v5/pkg/util"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -283,6 +284,10 @@ func NodeAddToClusterRemote(ctx context.Context, runtime runtimes.Runtime, node
 	node.RuntimeLabels[k3d.LabelClusterExternal] = "true"
 	node.RuntimeLabels[k3d.LabelClusterToken] = createNodeOpts.ClusterToken
 
+	if node.Image == "" { // we don't set a default, because on local clusters the value is copied from existing nodes
+		node.Image = fmt.Sprintf("%s:%s", k3d.DefaultK3sImageRepo, version.K3sVersion)
+	}
+
 	if node.Env == nil {
 		node.Env = []string{}
 	}
