@@ -30,9 +30,9 @@ import (
 	"os"
 	"time"
 
-	"github.com/rancher/k3d/v5/pkg/runtimes/docker"
-	runtimeTypes "github.com/rancher/k3d/v5/pkg/runtimes/types"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes/docker"
+	runtimeTypes "github.com/k3d-io/k3d/v5/pkg/runtimes/types"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
 )
 
 // SelectedRuntime is a runtime (pun intended) variable determining the selected runtime
